@@ -1,6 +1,7 @@
 import requests
 from lxml import etree
 from collections import OrderedDict
+from xmltodict import unparse
 from zeep import Client
 from zeep.cache import SqliteCache
 from zeep.transports import Transport
@@ -2298,16 +2299,19 @@ class remotePhoneAccess:
         :return:
         """
         messages = []
-        d = OrderedDict(
-            [("CiscoIPPhoneExecute", OrderedDict(
-                [("ExecuteItem", OrderedDict([("@Priority", "0"), ("@URL", keyPress)])
+        for kp in keyPress:
+            d = OrderedDict(
+                [("CiscoIPPhoneExecute", OrderedDict(
+                    [("ExecuteItem", OrderedDict([("@Priority", "0"), ("@URL", kp)])
+                      )])
                   )])
-              )])
-        messages.append({"XML": unparse(d)})
+            messages.append({"XML": unparse(d)})
+            # messages = [{   Code here and below is the XML to send popup messages to a phone!!
+            #     'XML': '<?xml version="1.0" encoding="utf-8"?>\n<CiscoIPPhoneText><Prompt>Prompt</Prompt><Text>Text</Text></CiscoIPPhoneText>'}]
         headers = {"content-type": "application/xml"}
         for key_press in messages:
             r = requests.post(
                 url="http://" + self.phone_ip + "/CGI/Execute",
                 data=key_press, verify=False, headers=headers, auth=(self.axlUsername, self.axlPassword)
             )
-            logging.info(r.text)
+        return r.text
